<?php

declare(strict_types=1);

namespace Drupal\aws;

use Drupal\aws\Entity\ProfileInterface;
use Drupal\aws\Traits\AwsServiceTrait;

/**
 * Factory class for AWS client instances.
 */
class AwsClientFactory implements AwsClientFactoryInterface {

  use AwsServiceTrait;

  /**
   * The profile to use when initializing clients.
   *
   * @var \Drupal\aws\Entity\ProfileInterface
   */
  protected $profile;

  /**
   * {@inheritdoc}
   */
  public function setProfile(ProfileInterface $profile) {
    $this->profile = $profile;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getClient($service_id) {
    $service = $this->aws->getService($service_id);

    if ($this->profile) {
      $client_args = $this->profile->getClientArgs();
    }
    else {
      $profile = $this->aws->getProfile($service_id);
      $client_args = $profile->getClientArgs();
    }

    $class = "\Aws\\{$service['namespace']}\\{$service['namespace']}Client";
    return new $class($client_args);
  }

}
